@@ -147,7 +147,7 @@ class ProjectTC(TrackerBaseTC):
                               [])
         # std user with perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
-        self.grant_permission('cubicweb', 'users', 'developer', 'soumettre sur cubicweb')
+        self.grant_permission(self.cubicweb, 'users', 'developer', 'soumettre sur cubicweb')
         # commit before opening a new connection
         self.commit()
         self.login('toto')
@@ -170,7 +170,7 @@ class ProjectTC(TrackerBaseTC):
                               [])
         # std user with client perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
-        self.grant_permission('cubicweb', 'users', 'client', 'nouvelle version')
+        self.grant_permission(self.cubicweb, 'users', 'client', 'nouvelle version')
         self.commit()
         # commit before opening a new connection
         self.login('toto')
@@ -472,7 +472,7 @@ class TicketTC(TrackerBaseTC):
 
     def test_version_publishing_cant_change_ticket_state(self):
         self.execute('INSERT CWGroup X: X name "cubicwebdevelopers"')
-        self.grant_permission('cubicweb', 'cubicwebdevelopers', u'developer')
+        self.grant_permission(self.cubicweb, 'cubicwebdevelopers', u'developer')
         self.create_user('prj1client', groups=('users', 'cubicwebdevelopers'))
         self.commit()
         self.t1.set_relations(done_in=self.v)
@@ -517,8 +517,8 @@ class CommentTC(AutoPopulateTest):
                 self.fail('%s class does not implement the project property' % etype)
 
 class FTITC(TrackerBaseTC):
-    """Version"""
-    config = ApptestConfiguration('data', sourcefile='sources_fti')
+    config = ApptestConfiguration('data', apphome=CommentTC.datadir,
+                                  sourcefile='sources_fti')
     @classmethod
     def _build_repo(cls, *args, **kwargs):
         try:
