@@ -1,7 +1,7 @@
 """some utilities for testing forge security
 
 :organization: Logilab
-:copyright: 2008-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2008-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -13,6 +13,7 @@ class ForgeSecurityTC(SecurityTC):
     def setUp(self):
         SecurityTC.setUp(self)
         # implicitly test manager can add some entities
-        self.execute('INSERT License X: X name "license"')
-        self.execute('INSERT ExtProject X: X name "projet externe"')
+        req = self.request()
+        req.create_entity('License', name=u'license')
+        self.extproject = req.create_entity('ExtProject', name=u'projet externe')
         self.commit()
