@@ -35,17 +35,19 @@ class FileIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
     def parent_entity(self):
         return self.entity.project
 
-    def breadcrumbs(self, view=None, recurs=False):
+    def breadcrumbs(self, view=None, recurs=None):
         entity = self.entity
         if entity.reverse_attachment:
             if entity.reverse_attachment[0].e_schema != 'Email':
                 ticket = entity.reverse_attachment[0]
-                path = ticket.cw_adapt_to('IBreadCrumbs').breadcrumbs(view, True)
+                path = ticket.cw_adapt_to('IBreadCrumbs').breadcrumbs(
+                    view, recurs or set())
                 path.append(entity)
                 return path
         if entity.project:
             project = entity.project
-            path = project.cw_adapt_to('IBreadCrumbs').breadcrumbs(view, True)
+            path = project.cw_adapt_to('IBreadCrumbs').breadcrumbs(
+                view, recurs or set())
             if entity.reverse_documented_by:
                 url = '%s/%s' % (entity.project.absolute_url(), 'documentation')
                 label = entity._cw._('documentation')
@@ -65,12 +67,14 @@ class CardIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
     def breadcrumbs(self, view=None, recurs=False):
         entity = self.entity
         if entity.project:
-            path = entity.project.cw_adapt_to('IBreadCrumbs').breadcrumbs(view, True)
+            path = entity.project.cw_adapt_to('IBreadCrumbs').breadcrumbs(
+                view, recurs or set())
             if entity.reverse_documented_by:
                 url = '%s/%s' % (entity.project.absolute_url(), 'documentation')
                 path.append( (url, self._cw._('documentation')) )
-            elif entity.test_case_for:
-                path = entity.test_case_for[0].cw_adapt_to('IBreadCrumbs').breadcrumbs(view, True)
+            elif getattr(entity, 'test_case_for', None):
+                path = entity.test_case_for[0].cw_adapt_to('IBreadCrumbs').breadcrumbs(
+                    view, recurs or set())
             else:
                 url = '%s/%s' % (entity.project.absolute_url(), 'testcases')
                 path.append( (url, self._cw._('test cases')) )
