@@ -1,7 +1,7 @@
 """some additional tabs for Ticket entities
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -12,10 +12,10 @@ from cubicweb.web import component
 from cubicweb.web.views import tabs
 
 
-class TicketTestCardVComponent(component.RelatedObjectsVComponent):
+class TicketTestCardCtxComponent(component.RelatedObjectsCtxComponent):
     """display project's test cards"""
     __regid__ = 'tickettests'
-    __select__ = component.RelatedObjectsVComponent.__select__ & is_instance('Ticket')
+    __select__ = component.RelatedObjectsCtxComponent.__select__ & is_instance('Ticket')
 
     rtype = 'test_case_for'
     target = 'subject'
